@@ -111,4 +111,12 @@ class LinkConfig(BaseModel):
 
     @classmethod
     async def from_model(cls: "LinkConfig", model: LinkModel) -> "LinkConfig":
-        return cls(**model.model_dump())
\ No newline at end of file
+        return cls(**model.model_dump())
+
+
+class AdPublishResult(BaseModel):
+    campaign_id: str
+    success: bool
+    code: str | None = None
+    ad_id: str | None = None
+    message: str | None = None
