@@ -12,10 +12,12 @@ from pydantic import BaseModel
 from ..general.dataclasses import ResolvableCompanyModel
 from ..integrations.dataclasses import LinkInfo
 from ..util.enum import to_enum
-from ..vacancies.models import Feed as FeedModel, Vacancy as VacancyModel, SalaryFrequency, RemoteType
 from ..util.vacancy import generate_vacancy_hash
 from ..services.clients import MSClient
 
+from ..vacancies.models import Feed as FeedModel, Vacancy as VacancyModel, SalaryFrequency, RemoteType
+from ..vacancies.models import Question as QuestionModel, Questionnaire as QuestionnaireModel, QuestionCategory
+
 class VacancyLocation(BaseModel):
     zipcode: str | None = None
     city: str | None = None
@@ -284,3 +286,28 @@ class FeedConfig(BaseModel):
     @classmethod
     async def from_model(cls: "FeedConfig", model: FeedModel) -> "FeedConfig":
         return cls(**model.model_dump())
+
+
+class QuestionnaireConfig(BaseModel):
+    id: UUID
+    created_at: datetime
+    updated_at: Optional[datetime]
+    organization: UUID
+
+    name: str
+    questions: list[QuestionConfig]
+
+
+class QuestionConfig(BaseModel):
+    questionnaire_id: UUID
+    question_category: QuestionCategory
+    key: str
+    label: Optional[str]
+    text: Optional[str]
+    type: str
+    required: bool
+    options: Optional[list]
+
+    @classmethod
+    async def from_model(cls: "QuestionnaireConfig", model: QuestionnaireModel) -> "QuestionnaireConfig":
+        return cls(**model.model_dump())
