@@ -23,6 +23,11 @@ class RemoteType(StrEnum):
     REMOTE = "remote"
 
 
+class QuestionCategory(StrEnum):
+    SCREENING = "screening"
+    DEMOGRAPHIC = "demographic"
+
+
 class SourceType(StrEnum):
     ATS = "ats"
     CUSTOM_FILE = "custom-file"
@@ -86,15 +91,31 @@ class Vacancy(VacanciesOrganizationModel, table=True):
     recruiter_email: Optional[str] = Field()
     recruiter_role: Optional[str] = Field()
     checksum: str = Field(index=True)
+    questionnaire_id: Optional[UUID] = Field(index=True)
 
     __table_args__ = (
         UniqueConstraint("feed_id", "reference_number", name="uq_feed_reference"),
     )
 
 
+class Questionnaire(VacanciesOrganizationModel, table=True):
+    name: str = Field(index=True)
+
+
+class Question(VacanciesOrganizationModel, table=True):
+    questionnaire_id: UUID = Field(index=True)
+    question_category: QuestionCategory = Field(sa_column=Column(Enum(QuestionCategory)))
+    key: str = Field(index=True)
+    label: Optional[str] = Field()
+    text: Optional[str] = Field()
+    type: str = Field()
+    required: bool = Field()
+    options: Optional[list] = Field(sa_column=Column(JSON))
+
+
 class Modification(VacanciesOrganizationModel, table=True):
     name: str = Field(index=True)
     type: str = Field(index=True)
-    selector_configuration: dict = Field(sa_column=Column(JSON))
-    changes_configuration: dict = Field(sa_column=Column(JSON))
+    selection_configuration: dict = Field(sa_column=Column(JSON))
+    modification_configuration: dict = Field(sa_column=Column(JSON))
 
